==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWidgets/QToolBarChangeEvent_shell.cpp <==
#include "QToolBarChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QToolBarChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QToolBarChangeEvent")
    QToolBarChangeEvent *_ptr = reinterpret_cast<QToolBarChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QToolBarChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QToolBarChangeEvent_shell) ); }

jmethodID QToolBarChangeEvent_shell::__shell_javaMethod(int pos) const { return QToolBarChangeEvent_shell::__shell()->javaMethod(typeid(QToolBarChangeEvent), pos); }

// emitting (writeShellConstructor)
QToolBarChangeEvent_shell::QToolBarChangeEvent_shell(const QToolBarChangeEvent& arg__1)
    : QToolBarChangeEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QToolBarChangeEvent::QToolBarChangeEvent_shell(const QToolBarChangeEvent& arg__1)", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->constructed(typeid(QToolBarChangeEvent));
}

QToolBarChangeEvent_shell::QToolBarChangeEvent_shell(bool t0)
    : QToolBarChangeEvent(t0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QToolBarChangeEvent::QToolBarChangeEvent_shell(bool t0)", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->constructed(typeid(QToolBarChangeEvent));
}

// emitting (writeShellDestructor)
QToolBarChangeEvent_shell::~QToolBarChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QToolBarChangeEvent::~QToolBarChangeEvent()", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->destructed(typeid(QToolBarChangeEvent));
}

void QToolBarChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QToolBarChangeEvent_shell*>(ptr)->QToolBarChangeEvent_shell::__shell()->tryDeleteShell(typeid(QToolBarChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QToolBarChangeEvent* QToolBarChangeEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QToolBarChangeEvent::clone()const", QToolBarChangeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QToolBarChangeEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QToolBarChangeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QToolBarChangeEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QToolBarChangeEvent_shell::__shell()->warnForMethod("QToolBarChangeEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QToolBarChangeEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QToolBarChangeEvent::clone();
        }
    }else{
        return QToolBarChangeEvent::clone();
    }
}

void QToolBarChangeEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QToolBarChangeEvent::", QToolBarChangeEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QToolBarChangeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QToolBarChangeEvent_shell::__shell()->warnForMethod("QToolBarChangeEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QToolBarChangeEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QToolBarChangeEvent_access::__qt_assign_cref_QToolBarChangeEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QToolBarChangeEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QToolBarChangeEvent>(__jni_env, other0);
    QToolBarChangeEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QToolBarChangeEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QToolBarChangeEvent* __qt_return_value = QToolBarChangeEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QToolBarChangeEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QToolBarChangeEvent(QToolBarChangeEvent)
void __qt_construct_QToolBarChangeEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QToolBarChangeEvent(QToolBarChangeEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QToolBarChangeEvent& __qt_arg__1 = qtjambi_cast<const QToolBarChangeEvent& >(__jni_env, arg__1);
    QToolBarChangeEvent *__qt_this = new(__qtjambi_ptr) QToolBarChangeEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QToolBarChangeEvent(bool)
void __qt_construct_QToolBarChangeEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QToolBarChangeEvent(bool)")
    jboolean t0 = __java_arguments[0].z;
    Q_UNUSED(t0)
    QToolBarChangeEvent *__qt_this = new(__qtjambi_ptr) QToolBarChangeEvent_shell(static_cast<bool>(t0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QToolBarChangeEvent_shell
void __qt_destruct_QToolBarChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QToolBarChangeEvent")
    reinterpret_cast<QToolBarChangeEvent_shell*>(ptr)->~QToolBarChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QToolBarChangeEvent::QToolBarChangeEvent(QToolBarChangeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_initialize_1native__Lio_qt_widgets_QToolBarChangeEvent_2Lio_qt_widgets_QToolBarChangeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolBarChangeEvent::QToolBarChangeEvent(QToolBarChangeEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QToolBarChangeEvent_0, sizeof(QToolBarChangeEvent_shell), typeid(QToolBarChangeEvent), true, &deleter_QToolBarChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolBarChangeEvent::QToolBarChangeEvent(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_initialize_1native__Lio_qt_widgets_QToolBarChangeEvent_2Z)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jboolean t0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolBarChangeEvent::QToolBarChangeEvent(bool)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.z = t0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QToolBarChangeEvent_1, sizeof(QToolBarChangeEvent_shell), typeid(QToolBarChangeEvent), true, &deleter_QToolBarChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolBarChangeEvent::operator=(QToolBarChangeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_assign_1native_1cref_1QToolBarChangeEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QToolBarChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QToolBarChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QToolBarChangeEvent::operator=(QToolBarChangeEvent)", __qt_this)
        static_cast<QToolBarChangeEvent_access*>(__qt_this)->__qt_assign_cref_QToolBarChangeEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolBarChangeEvent::toggle()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_toggle_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QToolBarChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QToolBarChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QToolBarChangeEvent::toggle()const", __qt_this)
        __java_return_value = __qt_this->toggle();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QToolBarChangeEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QToolBarChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QToolBarChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QToolBarChangeEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QToolBarChangeEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QToolBarChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QToolBarChangeEvent>("QToolBarChangeEvent", "io/qt/widgets/QToolBarChangeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/widgets/QToolBarChangeEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QToolBarChangeEvent, {
        ConstructorInfo(&__qt_construct_QToolBarChangeEvent_0, "Lio/qt/widgets/QToolBarChangeEvent;")
       ,ConstructorInfo(&__qt_construct_QToolBarChangeEvent_1, "Z")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QToolBarChangeEvent);
    registerSizeOfShell(typeId, sizeof(QToolBarChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QToolBarChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWidgets/QToolBarChangeEvent_shell.cpp <==
#include "QToolBarChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QToolBarChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QToolBarChangeEvent")
    QToolBarChangeEvent *_ptr = reinterpret_cast<QToolBarChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QToolBarChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QToolBarChangeEvent_shell) ); }

jmethodID QToolBarChangeEvent_shell::__shell_javaMethod(int pos) const { return QToolBarChangeEvent_shell::__shell()->javaMethod(typeid(QToolBarChangeEvent), pos); }

// emitting (writeShellConstructor)
QToolBarChangeEvent_shell::QToolBarChangeEvent_shell(const QToolBarChangeEvent& arg__1)
    : QToolBarChangeEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QToolBarChangeEvent::QToolBarChangeEvent_shell(const QToolBarChangeEvent& arg__1)", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->constructed(typeid(QToolBarChangeEvent));
}

QToolBarChangeEvent_shell::QToolBarChangeEvent_shell(bool t0)
    : QToolBarChangeEvent(t0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QToolBarChangeEvent::QToolBarChangeEvent_shell(bool t0)", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->constructed(typeid(QToolBarChangeEvent));
}

// emitting (writeShellDestructor)
QToolBarChangeEvent_shell::~QToolBarChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QToolBarChangeEvent::~QToolBarChangeEvent()", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->destructed(typeid(QToolBarChangeEvent));
}

void QToolBarChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QToolBarChangeEvent_shell*>(ptr)->QToolBarChangeEvent_shell::__shell()->tryDeleteShell(typeid(QToolBarChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QToolBarChangeEvent* QToolBarChangeEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QToolBarChangeEvent::clone()const", QToolBarChangeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QToolBarChangeEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QToolBarChangeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QToolBarChangeEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QToolBarChangeEvent_shell::__shell()->warnForMethod("QToolBarChangeEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QToolBarChangeEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QToolBarChangeEvent::clone();
        }
    }else{
        return QToolBarChangeEvent::clone();
    }
}

void QToolBarChangeEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QToolBarChangeEvent::", QToolBarChangeEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QToolBarChangeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QToolBarChangeEvent_shell::__shell()->warnForMethod("QToolBarChangeEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QToolBarChangeEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QToolBarChangeEvent_access::__qt_assign_cref_QToolBarChangeEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QToolBarChangeEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QToolBarChangeEvent>(__jni_env, other0);
    QToolBarChangeEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QToolBarChangeEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QToolBarChangeEvent* __qt_return_value = QToolBarChangeEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QToolBarChangeEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QToolBarChangeEvent(QToolBarChangeEvent)
void __qt_construct_QToolBarChangeEvent_cref_QToolBarChangeEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QToolBarChangeEvent(QToolBarChangeEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QToolBarChangeEvent& __qt_arg__1 = qtjambi_cast<const QToolBarChangeEvent& >(__jni_env, arg__1);
    QToolBarChangeEvent *__qt_this = new(__qtjambi_ptr) QToolBarChangeEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QToolBarChangeEvent::QToolBarChangeEvent(QToolBarChangeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_initialize_1native__Lio_qt_widgets_QToolBarChangeEvent_2Lio_qt_widgets_QToolBarChangeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolBarChangeEvent::QToolBarChangeEvent(QToolBarChangeEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QToolBarChangeEvent_cref_QToolBarChangeEvent, sizeof(QToolBarChangeEvent_shell), typeid(QToolBarChangeEvent), true, &deleter_QToolBarChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QToolBarChangeEvent(bool)
void __qt_construct_QToolBarChangeEvent_bool(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QToolBarChangeEvent(bool)")
    jboolean t0 = __java_arguments[0].z;
    Q_UNUSED(t0)
    QToolBarChangeEvent *__qt_this = new(__qtjambi_ptr) QToolBarChangeEvent_shell(static_cast<bool>(t0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QToolBarChangeEvent::QToolBarChangeEvent(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_initialize_1native__Lio_qt_widgets_QToolBarChangeEvent_2Z)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jboolean t0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolBarChangeEvent::QToolBarChangeEvent(bool)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.z = t0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QToolBarChangeEvent_bool, sizeof(QToolBarChangeEvent_shell), typeid(QToolBarChangeEvent), true, &deleter_QToolBarChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QToolBarChangeEvent_shell
void __qt_destruct_QToolBarChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QToolBarChangeEvent")
    reinterpret_cast<QToolBarChangeEvent_shell*>(ptr)->~QToolBarChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QToolBarChangeEvent::operator=(QToolBarChangeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_assign_1native_1cref_1QToolBarChangeEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QToolBarChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QToolBarChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QToolBarChangeEvent::operator=(QToolBarChangeEvent)", __qt_this)
        static_cast<QToolBarChangeEvent_access*>(__qt_this)->__qt_assign_cref_QToolBarChangeEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolBarChangeEvent::toggle()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_toggle_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QToolBarChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QToolBarChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QToolBarChangeEvent::toggle()const", __qt_this)
        __java_return_value = __qt_this->toggle();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QToolBarChangeEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QToolBarChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QToolBarChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QToolBarChangeEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QToolBarChangeEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QToolBarChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QToolBarChangeEvent>("QToolBarChangeEvent", "io/qt/widgets/QToolBarChangeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/widgets/QToolBarChangeEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QToolBarChangeEvent, {
        ConstructorInfo(&__qt_construct_QToolBarChangeEvent_cref_QToolBarChangeEvent, "Lio/qt/widgets/QToolBarChangeEvent;")
       ,ConstructorInfo(&__qt_construct_QToolBarChangeEvent_bool, "Z")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QToolBarChangeEvent);
    registerSizeOfShell(typeId, sizeof(QToolBarChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QToolBarChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
